==> config_widget-0.0.6.tar.gz: bin/analyze/analyze_single_file.dart <==
import 'package:analyzer/dart/analysis/analysis_context.dart';
import 'package:analyzer/dart/analysis/results.dart';
import 'package:analyzer/dart/analysis/session.dart';
import 'package:analyzer/dart/ast/ast.dart';
import 'package:analyzer/dart/ast/visitor.dart';
import 'package:config_widget/src/const.dart';

Map<String, dynamic> catchMap = {};
List<ConfigType> defaultList = [
  ConfigType.configDefault,
  ConfigType.noDisplay,
  ConfigType.disableTap,
];

Future<List<Map<String, dynamic>>> analyzeSingleFile(AnalysisContext context, String path) async {
  AnalysisSession session = context.currentSession;
  ParsedUnitResult resultA = await session.getParsedUnit2(path) as ParsedUnitResult;

  FileVisit fileVisit = FileVisit();
  resultA.unit.visitChildren(fileVisit);
  List<Map<String, dynamic>> result = fileVisit.resultList.map((e) {
    if (e.containsKey('children')) {
      List<Map<String, dynamic>> list = e['children'];
      List<String> result = ["默认显示", "隐藏", "不可以点击"];
      List<String> temp = list.map((element) => element['itemDescription'] as String).toList();
      if (temp != null) {
        result.addAll(temp);
      }
      e.addAll({'itemDescription': result});
      e.remove('children');
    }

    String key = e['configKey'] as String;
    e.remove('configKey');
    return {key: e};
  }).toList();

  return result;
}

class FileVisit extends RecursiveAstVisitor<Map<String, dynamic>> {
  List<Map<String, dynamic>> resultList = [];
  @override
  Map<String, dynamic> visitClassDeclaration(ClassDeclaration node) {
    return super.visitClassDeclaration(node);
  }

  @override
  Map<String, dynamic> visitMethodInvocation(MethodInvocation node) {
    Map<String, dynamic> result = {};
    if (node.methodName.toString() == 'ConfigAdapter') {
      ConfigAdapterVisit visit = ConfigAdapterVisit();
      node.childEntities.forEach((element) {
        if (element is ArgumentList) {
          element.arguments.forEach((element2) {
            result.addAll(visit.visitNamedExpression(element2));
          });
        }
      });
    } else {
      super.visitMethodInvocation(node);
    }
    if (result.isNotEmpty) {
      resultList.add(result);
    }
    return result;
  }
}

class ConfigAdapterVisit extends RecursiveAstVisitor<Map<String, dynamic>> {
  @override
  Map<String, dynamic> visitNamedExpression(NamedExpression node) {
    if (node.name.label.name == "configKey" || node.name.label.name == 'configDescription') {
      return {node.name.label.name: getString(node.expression)};
    } else if (node.name.label.name == "children" && node.expression is ListLiteral) {
      List<Map<String, dynamic>> list = [];
      node.expression.childEntities.forEach((element2) {
        ConfigItemVisit configItemVisit = ConfigItemVisit();
        if (element2 is MethodInvocation) {
          list.addAll(configItemVisit.visitMethodInvocation(element2));
        }
      });
      if (list.isNotEmpty) {
        return {node.name.label.name: list};
      }
    }

    return null;
  }
}

class ConfigItemVisit extends RecursiveAstVisitor<List<Map<String, dynamic>>> {
  @override
  List<Map<String, dynamic>> visitNamedExpression(NamedExpression node) {
    if (node.name.label.name == "itemDescription") {
      return [
        {node.name.label.name: getString(node.expression)}
      ];
    }
    return null;
  }

  @override
  List<Map<String, dynamic>> visitMethodInvocation(MethodInvocation node) {
    List<Map<String, dynamic>> list = [];
    node.childEntities.forEach((element) {
      if (element is ArgumentList) {
        element.arguments.forEach((element2) {
          List<Map<String, dynamic>> temp = this.visitNamedExpression(element2);
          if (temp != null) {
            list.addAll(temp);
          }
        });
      }
    });
    return list;
  }
}

String getString(var expression) {
  if (expression is SimpleStringLiteral) {
    return expression.value;
  } else {
    return expression.toString();
  }
}

==> config_widget-0.0.7.tar.gz: bin/analyze/analyze_single_file.dart <==
import 'package:analyzer/dart/analysis/analysis_context.dart';
import 'package:analyzer/dart/analysis/results.dart';
import 'package:analyzer/dart/analysis/session.dart';
import 'package:analyzer/dart/ast/ast.dart';
import 'package:analyzer/dart/ast/visitor.dart';
import 'package:config_widget/src/const.dart';

Map<String, dynamic> catchMap = {};
List<ConfigType> defaultList = [
  ConfigType.configDefault,
  ConfigType.noDisplay,
  ConfigType.disableTap,
];

Future<List<Map<String, dynamic>>> analyzeSingleFile(AnalysisContext context, String path) async {
  AnalysisSession session = context.currentSession;
  ParsedUnitResult resultA = session.getParsedUnit2(path) as ParsedUnitResult;

  FileVisit fileVisit = FileVisit();
  resultA.unit.visitChildren(fileVisit);
  List<Map<String, dynamic>> result = fileVisit.resultList.map((e) {
    if (e.containsKey('children')) {
      List<Map<String, dynamic>> list = e['children'];
      List<String> result = ["默认显示", "隐藏", "不可以点击"];
      List<String> temp = list.map((element) => element['itemDescription'] as String).toList();
      if (temp != null) {
        result.addAll(temp);
      }
      e.addAll({'itemDescription': result});
      e.remove('children');
    }

    String key = e['configKey'] as String;
    e.remove('configKey');
    return {key: e};
  }).toList();

  return result;
}

class FileVisit extends RecursiveAstVisitor<Map<String, dynamic>> {
  List<Map<String, dynamic>> resultList = [];
  @override
  Map<String, dynamic> visitClassDeclaration(ClassDeclaration node) {
    return super.visitClassDeclaration(node);
  }

  @override
  Map<String, dynamic> visitMethodInvocation(MethodInvocation node) {
    Map<String, dynamic> result = {};
    if (node.methodName.toString() == 'ConfigAdapter') {
      ConfigAdapterVisit visit = ConfigAdapterVisit();
      node.childEntities.forEach((element) {
        if (element is ArgumentList) {
          element.arguments.forEach((element2) {
            result.addAll(visit.visitNamedExpression(element2));
          });
        }
      });
    } else {
      super.visitMethodInvocation(node);
    }
    if (result.isNotEmpty) {
      resultList.add(result);
    }
    return result;
  }
}

class ConfigAdapterVisit extends RecursiveAstVisitor<Map<String, dynamic>> {
  @override
  Map<String, dynamic> visitNamedExpression(NamedExpression node) {
    if (node.name.label.name == "configKey" || node.name.label.name == 'configDescription') {
      return {node.name.label.name: getString(node.expression)};
    } else if (node.name.label.name == "children" && node.expression is ListLiteral) {
      List<Map<String, dynamic>> list = [];
      node.expression.childEntities.forEach((element2) {
        ConfigItemVisit configItemVisit = ConfigItemVisit();
        if (element2 is MethodInvocation) {
          list.addAll(configItemVisit.visitMethodInvocation(element2));
        }
      });
      if (list.isNotEmpty) {
        return {node.name.label.name: list};
      }
    }

    return null;
  }
}

class ConfigItemVisit extends RecursiveAstVisitor<List<Map<String, dynamic>>> {
  @override
  List<Map<String, dynamic>> visitNamedExpression(NamedExpression node) {
    if (node.name.label.name == "itemDescription") {
      return [
        {node.name.label.name: getString(node.expression)}
      ];
    }
    return null;
  }

  @override
  List<Map<String, dynamic>> visitMethodInvocation(MethodInvocation node) {
    List<Map<String, dynamic>> list = [];
    node.childEntities.forEach((element) {
      if (element is ArgumentList) {
        element.arguments.forEach((element2) {
          List<Map<String, dynamic>> temp = this.visitNamedExpression(element2);
          if (temp != null) {
            list.addAll(temp);
          }
        });
      }
    });
    return list;
  }
}

String getString(var expression) {
  if (expression is SimpleStringLiteral) {
    return expression.value;
  } else {
    return expression.toString();
  }
}
